.. image:: https://travis-ci.org/opennode/waldur-core.svg?branch=develop
    :target: https://travis-ci.org/opennode/waldur-core
    :alt: Build status

Waldur Core
===========

Waldur Core is an open-source RESTful server for multi-tenant resource management. It provides an
easy way for sharing access to external systems. It is used as a platform for creating private and
public clouds.

Additional information can be found at http://docs.waldur.com.

Support
=======

Professional support options are available. Please contact info@opennodecloud.com for details.


Development environment setup
-----------------------------

Instructions here: https://github.com/opennode/waldur-core/blob/develop/docs/guide/install-from-src.rst.
